<template>
  <AppHead :title="data.title" />
  <div class="container page-container">
    <PageTitle :title="data.title">
      <Link
        class="btn btn-sm btn-success me-2"
        :href="route('admin.applicants.show', data.applicant_uuid)"
      >
        <i class="fa-solid fa-id-card-clip"></i> {{ __("Show Profile") }}
      </Link>
      <Link class="btn btn-sm btn-light" :href="route('admin.applicants.index')">
        <i class="fa-solid fa-arrow-left-long"></i> {{ __("back to") }}
        {{ __("List of Applicants") }}
      </Link>
    </PageTitle>
    <div class="row">
      <div class="col-md-12">
        <hr />
      </div>
      <div class="col-md-8 border-end">
        <Fieldset :title="__('Writing Assessment')">
          <div v-if="data.assessment">
            <small class="text-muted">{{ __("Writing Topic") }}:</small>
            <h5>{{ data.assessment.essay_topic }}</h5>
            <small class="text-muted">{{ __("Instructions") }}:</small>
            <p v-html="data.assessment.essay_instructions"></p> 
            
            <div v-if="data.assessment.submitted_text" class="bg-light p-2">
              <small class="tex-center">{{ __("Submitted Writing") }}:</small>
              <div
                class="nl2br p-2 bg-white"
                v-html="data.assessment.submitted_text"
              ></div>
            </div>
            <div v-else>
              <small class="text-muted">{{ __("Has not submitted yet") }}</small>
            </div>
          </div>
          <div v-else>
            {{ __("Has not taken the assessment exam") }}
          </div>
        </Fieldset>
      </div>

      <div class="col-md-4">
        <div class="" v-if="data.assessment">
          <div class="border p-4">
            <div class="mb-2 border-bottom">
              <div class="fw-bold">{{ __("MCQ Score") }}:</div>
              <small>
                {{ data.assessment.mcq_score ? data.assessment.mcq_score : 0 }} out of
                {{ data.assessment.total_mcq_questions }}
              </small>
            </div>

            <div class="mb-2 border-bottom">
              <div class="fw-bold">{{ __("MCQ Answered") }}:</div>
              <small>{{ data.assessment.total_answered }}</small>
            </div>

            <div class="mb-2 border-bottom">
              <div class="fw-bold">{{ __("MCQ Passing Score") }}:</div>
              <small>{{ data.assessment.mcq_passing_score }}</small>
            </div>

            <div class="mb-2 border-bottom">
              <div class="fw-bold">{{ __("MCQ Start Time") }}:</div>
              <small>{{ localDateTime(data.assessment.mcq_start_time) }}</small>
            </div>

            <div class="mb-2 border-bottom">
              <div class="fw-bold">{{ __("MCQ Finished At") }}:</div>
              <small>
                <span v-if="data.assessment.mcq_finished_at">
                  {{ localDateTime(data.assessment.mcq_finished_at) }}
                </span>
                <span v-else>{{ __("Unfinished") }}</span>
              </small>
            </div>

            <div class="mb-2 border-bottom">
              <div class="fw-bold">{{ __("Writing Submission Deadline") }}:</div>
              <small>
                <span v-if="data.assessment.text_submission_due_at">
                  {{ localDateTime(data.assessment.text_submission_due_at) }}
                </span>
                <span v-else>{{ __("Waiting for MCQ Score") }}</span>
              </small>
            </div>

            <div class="mb-2 border-bottom">
              <div class="fw-bold">{{ __("Writing Submitted At") }}:</div>
              <small>
                <span v-if="data.assessment.text_submitted_at">
                  {{ localDateTime(data.assessment.text_submitted_at) }}
                </span>
                <span v-else>{{ __("Not Submitted") }}</span>
              </small>
            </div>
          </div>
        </div>
      </div>
    </div>

    <div class="row">
      <div class="col-md-12">
        <hr />
        <Fieldset :title="__('Multiple Choice Questions and Answers')">

        <div
          class="mb-4"
          v-for="(question, index) in data.assessment.questions"
          :key="index"
        >
          <div></div>
          <h5>#{{ question.number }} - {{ question.question_text }}</h5>
          <div>a) {{ question.option_a }}</div>
          <div>b) {{ question.option_b }}</div>
          <div>c) {{ question.option_c }}</div>
          <div>d) {{ question.option_d }}</div>
          <div class="fw-bold mt-3">
            <span class="text-primary"
              >{{ __("Correct Answer") }}: {{ question.correct_option }}</span
            >
            <span
              :class="`${
                question.correct_option == question.entered_option
                  ? 'text-success'
                  : 'text-danger'
              }`"
              > , {{ __("Chosen Answer") }}: {{ question.entered_option }}</span
            >
          </div>
          <hr />
        </div>
      </Fieldset>
      </div>
    </div>
  </div>
</template>

<script>
import Fieldset from "../../../components/Fieldset.vue";

export default {
  props: ["data"],
  components: {
    Fieldset,
  },
};
</script>
